KommunicateFlutterPluginWeb class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildConversation(dynamic conversationObject) → Future
handleMethodCall(MethodCall call) → Future
isLoggedIn() → Future
login(dynamic kmUser) → Future
loginAsVisitor(String appId) → Future
logout() → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openConversations() → Future
openParticularConversation(String clientConversationId) → Future
platformVersion() → Future
sendMessage(dynamic messageData) → Future
showChatWidget(bool isVisible) → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void